@@ -179,9 +179,9 @@ protected:
                 for (std::vector<int>::size_type v = 0; v < gr_idx.size(); ++v)
                 {
                     int c_idx = gr_idx[v];
-                    ds_norm += pow(vec(c_idx), 2);
+                    ds_norm += std::pow(vec(c_idx), 2);
                 }
-                ds_norm = sqrt(ds_norm);
+                ds_norm = std::sqrt(ds_norm);
                 // double grp_wts = sqrt(gr_idx.size());
                 double grp_wts = pen_fact(g);
                 thresh_factor = std::max(0.0, 1 - penalty * grp_wts / (ds_norm) );
@@ -300,7 +300,7 @@ protected:
                         // penalty for group 0
                         group_weights(g) = 0;
                     } else {
-                        group_weights(g) = sqrt(double(grp_idx[g].size()));
+                        group_weights(g) = std::sqrt(double(grp_idx[g].size()));
                     }
                 }
             }
