@@ -190,9 +190,9 @@ protected:
                 for (std::vector<int>::size_type v = 0; v < gr_idx.size(); ++v)
                 {
                     int c_idx = gr_idx[v];
-                    ds_norm += pow(vec(c_idx), 2);
+                    ds_norm += std::pow(vec(c_idx), 2);
                 }
-                ds_norm = sqrt(ds_norm);
+                ds_norm = std::sqrt(ds_norm);
                 // double grp_wts = sqrt(gr_idx.size());
                 double grp_wts = pen_fact(g);
                 thresh_factor = std::max(0.0, 1 - penalty * grp_wts / (ds_norm) );
@@ -351,7 +351,7 @@ protected:
                 group_weights.resize(ngroups);
                 for (int g = 0; g < ngroups; ++g) 
                 {
-                    group_weights(g) = sqrt(double(grp_idx[g].size()));
+                    group_weights(g) = std::sqrt(double(grp_idx[g].size()));
                 }
             }
         }
@@ -394,7 +394,7 @@ protected:
                     }
                         
                     xxdiag = XX.diagonal().tail(nvars).mean();
-                    intval = sqrt(xxdiag / double(nobs));
+                    intval = std::sqrt(xxdiag / double(nobs));
                     
                     Eigen::RowVectorXd colsums = X.adjoint() * weights; 
                     colsums.array() *= intval;
@@ -444,7 +444,7 @@ protected:
                     }
                     
                     xxdiag = XX.diagonal().tail(nvars).mean();
-                    intval = sqrt(xxdiag / nobs);
+                    intval = std::sqrt(xxdiag / nobs);
                     
                     Eigen::RowVectorXd colsums = X.adjoint() * VectorXd::Ones( nobs );
                     colsums.array() *= intval;
